{ *** DEMO FOR the IngisWDEF WDEF building package *** }

{ 1994-1995 by Ingemar Ragnemalm}
{You may use it freely as long as credits are given in the final program.}


{A simple example window. Rounded rect with a drag bar that is narrower than the content region. Window name}
{not drawn; the drag area is painted blue/black. Supports close box but no zoom or grow boxes.}
{}
{In this example, many routines are left empty. Only the folowing routines are used: GetCloseBox, DrawCloseBox,}
{DrawHitCloseBox, DrawDragBar and BuildCustomRegions. Can it be simpler?}


{This unit holds all custom code}

unit CustomStubs;

interface
	uses
{$IFC UNDEFINED THINK_PASCAL}
		Types, QuickDraw, ToolUtils, Windows, 
{$ENDC}
		IngisWDEFUtils;

	procedure GetGrowRgn (varCode: integer; macWindow: WindowPeek; var growRgn: RgnHandle);
	procedure GetCloseBox (varCode: integer; dragBar: RgnHandle; var closeBox: Rect);
	procedure GetZoomBox (varCode: integer; dragBar: RgnHandle; var zoomBox: Rect);
	procedure DrawCloseBox (varCode: integer; macWindow: WindowPeek; closeBox: Rect; colorFlag: Boolean);
	procedure DrawZoomBox (varCode: integer; macWindow: WindowPeek; zoomBox: Rect; colorFlag: Boolean);
	procedure DrawHitCloseBox (varCode: integer; macWindow: WindowPeek; closeBox: Rect; colorFlag: Boolean);
	procedure DrawHitZoomBox (varCode: integer; macWindow: WindowPeek; zoomBox: Rect; colorFlag: Boolean);
	procedure DrawDragBar (varCode: integer; macWindow: WindowPeek; dragBar: RgnHandle; colorFlag: Boolean);
	procedure BuildCustomRegions (varCode: integer; theRect: Rect; contRgn, dragRgn: RgnHandle);
	procedure DrawScrollFrame (varCode: integer; macWindow: WindowPeek; theRect: Rect);
	procedure DrawTheGrowIcon (varCode: integer; macWindow: WindowPeek; theRect: Rect; growRgn: RgnHandle; colorFlag: Boolean);
	procedure InitMyWindow (varCode: integer; macWindow: WindowPeek);
	procedure DisposeMyWindow (varCode: integer; macWindow: WindowPeek);

{** Constants **}
	const
		kFrameWidth = 1;		{ Thickness of frame around window. 1 is normal.}
		kShadowLength = 1;		{ Size of drop shadow. 1 is normal.}
		kMinDepthForColor = 4;	{ Smallest pixel size for color. 8 (256 colors) is normal. }
		kMinWidth = 100;		{ Limits for the dragging rectangle? }
		kMinHeight = 100;

implementation

{*****************************************************************************}
{ GetGrowRgn}
{		Return the region with the grow icon, if any.}
{ *****************************************************************************}

	procedure GetGrowRgn (varCode: integer; macWindow: WindowPeek; var growRgn: RgnHandle);
	begin
{We don't support resizing}
	end;

{*****************************************************************************}
{ GetCloseBox}
{		Pass back a rectangle which encloses the close box of the window}
{ *****************************************************************************}

	procedure GetCloseBox (varCode: integer; dragBar: RgnHandle; var closeBox: Rect);
	begin
		with dragBar^^.rgnBBox do
			SetRect(closeBox, left + 5, top + 3, left + 5 + (bottom - top - 4) - 2, bottom - 3);
	end;

	procedure GetZoomBox (varCode: integer; dragBar: RgnHandle; var zoomBox: Rect);
	begin
{No zoom box}
	end;

{*****************************************************************************}
{ Draw close box and zoom box, in normal and hit state }
{		Draw the close box in "hit" state. This can be as simple as an InvertRect. }
{ *****************************************************************************}

	procedure DrawCloseBox (varCode: integer; macWindow: WindowPeek; closeBox: Rect; colorFlag: Boolean);
	begin
		StdCloseBox(closeBox, colorFlag);
	end; {}
	procedure DrawZoomBox (varCode: integer; macWindow: WindowPeek; zoomBox: Rect; colorFlag: Boolean);
	begin
{No zoom box}
	end; {}
	procedure DrawHitCloseBox (varCode: integer; macWindow: WindowPeek; closeBox: Rect; colorFlag: Boolean);
	begin
{InvertRect(closeBox);}
		if colorFlag then
			begin
{$IFC UNDEFINED THINK_PASCAL}
				RGBForeColor(BoxShadowColor());
				RGBBackColor(BoxFillColor());
{$ELSEC}
				RGBForeColor(BoxShadowColor);
				RGBBackColor(BoxFillColor);
{$ENDC}
			end;
		DrawStdCloseHit(closeBox);
	end; {}
	procedure DrawHitZoomBox (varCode: integer; macWindow: WindowPeek; zoomBox: Rect; colorFlag: Boolean);
	begin
	end; {}

{*****************************************************************************}
{ DrawDragBar, BW and Color version}
{		Draw the drag bar (not close box/zoom box)}
{ *****************************************************************************}

	procedure DrawDragBar (varCode: integer; macWindow: WindowPeek; dragBar: RgnHandle; colorFlag: Boolean);
	begin
		if colorFlag then
			if macWindow^.hilited then
{$IFC UNDEFINED THINK_PASCAL}
				RGBForeColor(BoxShadowColor())
			else
				RGBForeColor(SurroundColor());
{$ELSEC}
				RGBForeColor(BoxShadowColor)
			else
				RGBForeColor(SurroundColor);
{$ENDC}
		PaintRgn(dragBar);
	end; {DrawDragBar}

{*****************************************************************************}
{ BuildCustomRegions}
{		Build the contents region and the drag bar region}
{ *****************************************************************************}

	procedure BuildCustomRegions (varCode: integer; theRect: Rect; contRgn, dragRgn: RgnHandle);
		var
			tmpRect: Rect;
	begin
		OpenRgn;
		FrameRoundRect(theRect, 10, 10);
		CloseRgn(contRgn);

		tmpRect := theRect;
		InsetRect(tmpRect, 15, 0);
		OffsetRect(tmpRect, 0, -18);
		OpenRgn;
		FrameRoundRect(tmpRect, 10, 10);
		CloseRgn(dragRgn);
	end; {BuildCustomRegions}

{*****************************************************************************}
{ DrawScrollFrame}
{		Draw the scroll frame, if any (used both when resizing and when drawing the grow icon) }
{ *****************************************************************************}

	procedure DrawScrollFrame (varCode: integer; macWindow: WindowPeek; theRect: Rect);
	begin
{No scroll frame - no resizing}
	end; {DrawScrollFrame}

{*****************************************************************************}
{ DrawTheGrowIcon, BW and Color version}
{		Draw the grow icon, if any }
{ *****************************************************************************}

	procedure DrawTheGrowIcon (varCode: integer; macWindow: WindowPeek; theRect: Rect; growRgn: RgnHandle; colorFlag: Boolean);
	begin
{No grow}
	end; {DrawTheGrowIcon}

{*****************************************************************************}
{ InitMyWindow and DisposeMyWindow }
{		Can often be empty. Set the spareFlag in InitMyWindow if the variant should have a zoom box. }
{ *****************************************************************************}

	procedure InitMyWindow (varCode: integer; macWindow: WindowPeek);
	begin
{No zoom}
	end; {}
	procedure DisposeMyWindow (varCode: integer; macWindow: WindowPeek);
	begin
	end; {}

end.